summaryrefslogtreecommitdiffstats
path: root/kdecore/kwinmodule.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kdecore/kwinmodule.cpp
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdecore/kwinmodule.cpp')
-rw-r--r--kdecore/kwinmodule.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kdecore/kwinmodule.cpp b/kdecore/kwinmodule.cpp
index f113570db..383bb76d5 100644
--- a/kdecore/kwinmodule.cpp
+++ b/kdecore/kwinmodule.cpp
@@ -172,7 +172,7 @@ const TQValueList<WId>& KWinModule::stackingOrder() const
bool KWinModule::hasWId(WId w) const
{
- return d->windows.findIndex( w ) != -1;
+ return d->windows.tqfindIndex( w ) != -1;
}
const TQValueList<WId>& KWinModule::systemTrayWindows() const
@@ -243,7 +243,7 @@ bool KWinModulePrivate::x11Event( XEvent * ev )
for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
emit (*mit)->showingDesktopChanged( showingDesktop());
}
- } else if ( windows.findIndex( ev->xany.window ) != -1 ){
+ } else if ( windows.tqfindIndex( ev->xany.window ) != -1 ){
NETWinInfo ni( qt_xdisplay(), ev->xany.window, qt_xrootwin(), 0 );
unsigned long dirty[ 2 ];
ni.event( ev, dirty, 2 );
@@ -257,7 +257,7 @@ bool KWinModulePrivate::x11Event( XEvent * ev )
}
if ( (dirty[ NETWinInfo::PROTOCOLS ] & NET::WMStrut) != 0 ) {
removeStrutWindow( ev->xany.window );
- if ( possibleStrutWindows.findIndex( ev->xany.window ) == -1 )
+ if ( possibleStrutWindows.tqfindIndex( ev->xany.window ) == -1 )
possibleStrutWindows.append( ev->xany.window );
}
if ( dirty[ NETWinInfo::PROTOCOLS ] || dirty[ NETWinInfo::PROTOCOLS2 ] ) {
@@ -295,7 +295,7 @@ void KWinModulePrivate::updateStackingOrder()
void KWinModulePrivate::addClient(Window w)
{
- if ( (what >= KWinModule::INFO_WINDOWS) && !TQWidget::find( w ) )
+ if ( (what >= KWinModule::INFO_WINDOWS) && !TQWidget::tqfind( w ) )
XSelectInput( qt_xdisplay(), w, PropertyChangeMask | StructureNotifyMask );
bool emit_strutChanged = false;
if( strutSignalConnected && modules.count() > 0 ) {
@@ -318,7 +318,7 @@ void KWinModulePrivate::addClient(Window w)
void KWinModulePrivate::removeClient(Window w)
{
bool emit_strutChanged = removeStrutWindow( w );
- if( strutSignalConnected && possibleStrutWindows.findIndex( w ) != -1 && modules.count() > 0 ) {
+ if( strutSignalConnected && possibleStrutWindows.tqfindIndex( w ) != -1 && modules.count() > 0 ) {
NETWinInfo info( qt_xdisplay(), w, qt_xrootwin(), NET::WMStrut );
NETStrut strut = info.strut();
if ( strut.left || strut.top || strut.right || strut.bottom ) {
@@ -382,16 +382,16 @@ TQRect KWinModule::workArea( int desktop ) const
{
int desk = (desktop > 0 && desktop <= (int) d->numberOfDesktops() ) ? desktop : currentDesktop();
if ( desk <= 0 )
- return TQApplication::desktop()->geometry();
+ return TQApplication::desktop()->tqgeometry();
NETRect r = d->workArea( desk );
if( r.size.width <= 0 || r.size.height <= 0 ) // not set
- return TQApplication::desktop()->geometry();
+ return TQApplication::desktop()->tqgeometry();
return TQRect( r.pos.x, r.pos.y, r.size.width, r.size.height );
}
TQRect KWinModule::workArea( const TQValueList<WId>& exclude, int desktop ) const
{
- TQRect all = TQApplication::desktop()->geometry();
+ TQRect all = TQApplication::desktop()->tqgeometry();
TQRect a = all;
if (desktop == -1)
@@ -400,10 +400,10 @@ TQRect KWinModule::workArea( const TQValueList<WId>& exclude, int desktop ) cons
TQValueList<WId>::ConstIterator it1;
for( it1 = d->windows.begin(); it1 != d->windows.end(); ++it1 ) {
- if(exclude.findIndex(*it1) != -1) continue;
+ if(exclude.tqfindIndex(*it1) != -1) continue;
// Kicker (very) extensively calls this function, causing hundreds of roundtrips just
// to repeatedly find out struts of all windows. Therefore strut values for strut
// windows are cached here.
NETStrut strut;
TQValueList< KWinModulePrivate::StrutData >::Iterator it2 = d->strutWindows.begin();
@@ -416,7 +416,7 @@ TQRect KWinModule::workArea( const TQValueList<WId>& exclude, int desktop ) cons
if(!((*it2).desktop == desktop || (*it2).desktop == NETWinInfo::OnAllDesktops ))
continue;
strut = (*it2).strut;
- } else if( d->possibleStrutWindows.findIndex( *it1 ) != -1 ) {
+ } else if( d->possibleStrutWindows.tqfindIndex( *it1 ) != -1 ) {
NETWinInfo info( qt_xdisplay(), (*it1), qt_xrootwin(), NET::WMStrut | NET::WMDesktop);
strut = info.strut();
d->possibleStrutWindows.remove( *it1 );
@@ -400,10 +400,10 @@ TQRect KWinModule::workArea( const TQValueList<WId>& exclude, int desktop ) cons
// Kicker (very) extensively calls this function, causing hundreds of roundtrips just
-// to repeatedly find out struts of all windows. Therefore strut values for strut
+// to repeatedly tqfind out struts of all windows. Therefore strut values for strut
// windows are cached here.
NETStrut strut;